@@ -3,7 +3,8 @@ from collections import defaultdict
 from robot.api.parsing import ModelTransformer, Token
 from robot.parsing.model import Statement
 
-from robotidy.utils import node_outside_selection, round_to_four, tokens_by_lines, left_align, is_blank_multiline
+from robotidy.disablers import skip_section_if_disabled
+from robotidy.utils import is_blank_multiline, left_align, round_to_four, tokens_by_lines
 
 
 class AlignSettingsSection(ModelTransformer):
@@ -66,12 +67,11 @@ class AlignSettingsSection(ModelTransformer):
         self.argument_indent = argument_indent
         self.min_width = min_width
 
+    @skip_section_if_disabled
     def visit_SettingSection(self, node):  # noqa
-        if node_outside_selection(node, self.formatting_config):
-            return node
         statements = []
         for child in node.body:
-            if node_outside_selection(child, self.formatting_config):
+            if self.disablers.is_node_disabled(child):
                 statements.append(child)
             elif child.type in (Token.EOL, Token.COMMENT):
                 statements.append(left_align(child))
