@@ -1,6 +1,8 @@
-from robot.api.parsing import ModelTransformer, EmptyLine
+from robot.api.parsing import EmptyLine, ModelTransformer
 from robot.parsing.model.blocks import Keyword
 
+from robotidy.disablers import skip_section_if_disabled
+
 
 class SmartSortKeywords(ModelTransformer):
     """
@@ -10,7 +12,7 @@ class SmartSortKeywords(ModelTransformer):
     treated as spaces.
     Empty lines (or lack of them) between keywords are preserved.
 
-    Following code::
+    Following code:
 
         *** Keywords ***
         _my secrete keyword
@@ -24,7 +26,7 @@ class SmartSortKeywords(ModelTransformer):
         my another keyword
             Kw3
 
-    Will be transformed to::
+    Will be transformed to:
 
         *** Keywords ***
         my_another_cool_keyword
@@ -40,17 +42,24 @@ class SmartSortKeywords(ModelTransformer):
 
     Default behaviour could be changed using following parameters: ``case_insensitive = True``,
     ``ignore_leading_underscore = False`` and ``ignore_other_underscore = True``.
+
+    See https://robotidy.readthedocs.io/en/latest/transformers/SmartSortKeywords.html for more examples.
     """
+
     ENABLED = False
 
-    def __init__(self, case_insensitive=True, ignore_leading_underscore=False, ignore_other_underscore=True):
+    def __init__(
+        self,
+        case_insensitive=True,
+        ignore_leading_underscore=False,
+        ignore_other_underscore=True,
+    ):
         self.ci = case_insensitive
         self.ilu = ignore_leading_underscore
         self.iou = ignore_other_underscore
 
+    @skip_section_if_disabled
     def visit_KeywordSection(self, node):  # noqa
-        if not node.body:
-            return node
         before, after = self.leave_only_keywords(node)
         empty_lines = self.pop_empty_lines(node)
         node.body.sort(key=self.sort_function)
@@ -83,9 +92,9 @@ class SmartSortKeywords(ModelTransformer):
         if self.ci:
             name = name.casefold().upper()  # to make sure that letters go before underscore
         if self.ilu:
-            name = name.lstrip('_')
+            name = name.lstrip("_")
         if self.iou:
-            index = len(name) - len(name.lstrip('_'))
+            index = len(name) - len(name.lstrip("_"))
             name = name[:index] + name[index:].replace("_", " ")
         return name
 
